/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.avro;

import java.io.File;
import java.io.IOException;
import org.apache.avro.generic.GenericData;
import org.apache.iceberg.Files;
import org.apache.iceberg.Schema;
import org.apache.iceberg.io.FileAppender;
import org.apache.iceberg.parquet.Parquet;
import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

public class TestParquetReadProjection extends TestReadProjection {
  @Override
  protected GenericData.Record writeAndRead(
      String desc, Schema writeSchema, Schema readSchema, GenericData.Record record)
      throws IOException {
    File file = temp.resolve(desc + ".parquet").toFile();
    file.delete();

    try (FileAppender<GenericData.Record> appender =
        Parquet.write(Files.localOutput(file)).schema(writeSchema).build()) {
      appender.add(record);
    }

    Iterable<GenericData.Record> records =
        Parquet.read(Files.localInput(file)).project(readSchema).callInit().build();

    return Iterables.getOnlyElement(records);
  }

  @Override
  @Test
  @Disabled("Empty struct read is not supported for Parquet")
  public void testEmptyStructProjection() throws Exception {}

  @Override
  @Test
  @Disabled("Empty struct read is not supported for Parquet")
  public void testEmptyStructRequiredProjection() throws Exception {}

  @Override
  @Test
  @Disabled("Empty struct read is not supported for Parquet")
  public void testRequiredEmptyStructInRequiredStruct() throws Exception {}

  @Override
  @Test
  @Disabled("Empty struct read is not supported for Parquet")
  public void testEmptyNestedStructProjection() throws Exception {}

  @Override
  @Test
  @Disabled("Empty struct read is not supported for Parquet")
  public void testEmptyNestedStructRequiredProjection() throws Exception {}
}
